/*
 * Copyright (C) 2008, Pino Toscano <pino@kde.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include "thumbnails.h"

#include <poppler-qt4.h>

#include <QtGui/QTableWidget>
#include <QtGui/QHeaderView>

ThumbnailsDock::ThumbnailsDock(QWidget *parent)
    : AbstractInfoDock(parent)
{
    m_table = new QTableWidget(this);
    setWidget(m_table);
    setWindowTitle(tr("Thumbnails"));
    m_table->setColumnCount(1);
	m_table->horizontalHeader()->setVisible(false);
	m_table->verticalHeader()->setVisible(false);
	connect(m_table, SIGNAL(activated(const QModelIndex &) ), 
			this, SLOT(clickedPage(const QModelIndex &)));
}

ThumbnailsDock::~ThumbnailsDock()
{
}

void ThumbnailsDock::fillInfo()
{
    //~ m_table->setRowCount(i + 1);
    //~ m_table->setItem(i, 0, new QTableWidgetItem(QString::fromLatin1(title)));
    //~ m_table->setItem(i, 1, new QTableWidgetItem(yesNoStatement(document()->function())));
    //~ ++i;
	int n = document()->numPages();
	m_table->setRowCount(n);
	for (int i = 0; i < n; ++i)
	{
		QImage im = document()->page(i)->thumbnail();
		if (!im.isNull())
		{
			QPixmap pm = QPixmap::fromImage(im);
			QIcon icon(pm);
			QTableWidgetItem* item = new QTableWidgetItem(icon, "");
			item->setSizeHint(im.size());
			m_table->setItem(i, 0, item);
		}
	}
}

void ThumbnailsDock::documentClosed()
{
    m_table->clear();
    m_table->setRowCount(0);
    AbstractInfoDock::documentClosed();
}

#include "thumbnails.moc"
